@@ -12,6 +12,8 @@
 
 #include "kcrash.h"
 
+#include "kcrash_debug.h"
+
 #include <config-kcrash.h>
 
 #include <signal.h>
@@ -46,17 +48,8 @@
 #include <QStandardPaths>
 #include <QThread>
 
-#include <QLoggingCategory>
-Q_DECLARE_LOGGING_CATEGORY(LOG_KCRASH)
-
-// logging category for this framework, default: log stuff >= info
-Q_LOGGING_CATEGORY(LOG_KCRASH, "kf.crash", QtInfoMsg)
-
 #if HAVE_X11
 #include <X11/Xlib.h>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#endif
 #endif
 
 #include "coreconfig_p.h"
@@ -181,7 +174,7 @@ static QStringList libexecPaths()
     static QStringList list = QFile::decodeName(qgetenv("LIBEXEC_PATH")).split(QLatin1Char(':'), Qt::SkipEmptyParts) // env var is used first
         + QStringList{
             QCoreApplication::applicationDirPath(), // then look where our application binary is located
-            QLibraryInfo::location(QLibraryInfo::LibraryExecutablesPath), // look where libexec path is (can be set in qt.conf)
+            QLibraryInfo::path(QLibraryInfo::LibraryExecutablesPath), // look where libexec path is (can be set in qt.conf)
             QFile::decodeName(KDE_INSTALL_FULL_LIBEXECDIR) // look at our installation location
         };
     return list;
@@ -351,12 +344,7 @@ void KCrash::setDrKonqiEnabled(bool enabled)
     }
     s_launchDrKonqi = launchDrKonqi;
     if (s_launchDrKonqi && !s_drkonqiPath) {
-#ifdef Q_OS_WINDOWS
-        static const QString drkonqi = QStringLiteral("drkonqi.exe");
-#else
-        static const QString drkonqi = QStringLiteral("drkonqi");
-#endif
-        const QString exec = QStandardPaths::findExecutable(drkonqi, libexecPaths());
+        const QString exec = QStandardPaths::findExecutable(QStringLiteral("drkonqi"), libexecPaths());
         if (exec.isEmpty()) {
             qCDebug(LOG_KCRASH) << "Could not find drkonqi in search paths:" << libexecPaths();
             s_launchDrKonqi = 0;
@@ -481,7 +469,11 @@ void KCrash::defaultCrashHandler(int sig)
         // The ini is required to be scoped here, as opposed to the conditional scope, so its lifetime is the same as
         // the regular data instance!
         MetadataINIWriter ini(s_metadataPath);
-        if (ini.isWritable()) {
+        // s_appFilePath can point to nullptr
+        // not exactly sure how, maybe some race condition due to KCrashDelaySetHandler ?
+        if (!s_appFilePath) {
+            fprintf(stderr, "KCrash: appFilePath points to nullptr!\n");
+        } else if (ini.isWritable()) {
             // Add the canonical exe path so the coredump daemon has more data points to map metadata to journald entry.
             ini.add("--exe", s_appFilePath.get(), MetadataWriter::BoolValue::No);
             data.setAdditionalWriter(&ini);
@@ -497,13 +489,8 @@ void KCrash::defaultCrashHandler(int sig)
         if (platformName == QByteArrayLiteral("xcb")) {
             // start up on the correct display
             char *display = nullptr;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            if (QX11Info::display()) {
-                display = XDisplayString(QX11Info::display());
-#else
             if (auto disp = qGuiApp->nativeInterface<QNativeInterface::QX11Application>()->display()) {
                 display = XDisplayString(disp);
-#endif
             } else {
                 display = getenv("DISPLAY");
             }
@@ -598,16 +585,10 @@ void KCrash::defaultCrashHandler(int sig)
             closeAllFDs();
         }
 #if HAVE_X11
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        else if (QX11Info::display()) {
-            close(ConnectionNumber(QX11Info::display()));
-        }
-#else
         else if (auto display = qGuiApp->nativeInterface<QNativeInterface::QX11Application>()->display()) {
             close(ConnectionNumber(display));
         }
 #endif
-#endif
 #endif
 
         if (s_launchDrKonqi != 1) {
